pub struct OpenGraphConfig {
pub type: Option<String>,
pub image: String,
pub image_alt_text: Option<String>,
pub url: Option<String>,
pub author: Option<String>,
}Expand description
OpenGraph configuration for the website.
Fields
type: Option<String>OpenGraph type of the website. It will be used as the og:type meta tag.
Note: by default, the value “website” will be enforced for the version listing page and “article” for the release notes page.
image: StringURL of the website’s image.
image_alt_text: Option<String>Alt text for the website’s image.
url: Option<String>URL of the website. If not set, the base_url will be used instead. If base_url is not set either, the world explodes. Think of the kittens.
Author of the website. Used on release notes pages to indicate the author.